<?php
/**
 * This is the entrypoint for the locrMAPS for WooCommerce WordPress plugin.
 *
 * @package locrMAPS for WooCommerce
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMapsForWooCommerce\DDD\ValueObjects;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

enum ImageType: string {
	case JPEG = 'jpeg';
	case PNG  = 'png';

	/**
	 * This function creates an image type from a value.
	 *
	 * @param string $value The value.
	 * @throws \InvalidArgumentException If the image type is invalid.
	 */
	public static function from_string( string $value ): self {
		return match ( $value ) {
			'jpg'   => self::JPEG,
			'jpeg'  => self::JPEG,
			'png'   => self::PNG,
			default => throw new \InvalidArgumentException( 'Invalid image type.' ),
		};
	}

	/**
	 * This function converts the image type to a file extension.
	 */
	public function to_file_extension(): string {
		return match ( $this ) {
			self::JPEG => 'jpeg',
			self::PNG  => 'png',
		};
	}
}
